# Math & FFT Utilities

Centered FFT functions and mathematical helpers for testing.

## Centered FFT

::: torchlinops.utils.cfftn

::: torchlinops.utils.cifftn

::: torchlinops.utils.cfft

::: torchlinops.utils.cifft

::: torchlinops.utils.cfft2

::: torchlinops.utils.cifft2

## Adjoint Helpers

::: torchlinops.utils.inner

::: torchlinops.utils.is_adjoint
